Seantis Plonetools
==================

A collection of tools shared with different Seantis Plone modules.

Requirements
------------

-  Python 2.7
-  Plone 4.3+
-  Linux / Posix ( Windows may or may not work )

Build Status
------------

.. image:: https://travis-ci.org/seantis/seantis.plonetools.png   
    :target: https://travis-ci.org/seantis/seantis.plonetools

Coverage
--------

.. image:: https://coveralls.io/repos/seantis/seantis.plonetools/badge.png
  :target: https://coveralls.io/r/seantis/seantis.plonetools

License
-------
seantis.plonetools is released under MIT
